<?php
$lang['delete'] = 'Poista';
$lang['cd_company'] = 'Yhti&ouml; Hakemisto Yhti&ouml;';
$lang['dflt_urlprefix'] = 'URL-osoitteiden oletus etuliite';
$lang['dflt_alldayevent'] = 'Uudet tapahtumat ovat oletuksena &quot;Koko p&auml;iv&auml;n&quot;-tapahtumia';
$lang['dflt_starttime'] = 'Uusien tapahtumien oletus alkamisaika';
$lang['info_dflt_starttime'] = '<em>(p&auml;tee ainoastaan, jos uudet tapahtumat eiv&auml;t ole &amp;quot;Koko p&auml;iv&auml;n&quot;-tapahtumia)</em>';
$lang['search_type'] = 'Hakutyyppi';
$lang['search_any'] = 'N&auml;yt&auml; tulokset, jotka t&auml;sm&auml;&auml;v&auml;t mihin tahansa sanaan';
$lang['search_all'] = 'N&auml;yt&auml; tulokset, jotka t&auml;sm&auml;&auml;v&auml;t kaikkiin sanoihin';
$lang['info_customfields'] = '<span style=&quot;color: red;&quot;>Huomaa:</span> &quot;Tiedostonl&auml;hetys&quot;-kentt&auml; ei ole haettavissa.';
$lang['searchable'] = 'Haettavissa';
$lang['help_param_editeventtemplate'] = 'Koskee ainoastaan myevents-toimintoa, t&auml;m&auml; parametri sallii m&auml;&auml;ritell&auml; oletuksesta poikkeavan sivupohjan tapahtumien muokkaamiseen, kun k&auml;ytt&auml;j&auml; luo tai muokkaa tapahtumaa.';
$lang['help_param_editpage'] = 'Koskee ainoastaan myevents-toimintoa, t&auml;m&auml; parametri sallii toisen sivun m&auml;&auml;rittelemisen lomakkeelle.';
$lang['help_param_myeventstemplate'] = 'Koskee ainoastaan myevents-toimintoa, t&auml;m&auml; sallii oletuksesta poikkeavan sivupohjan m&auml;&auml;rittelemisen.';
$lang['cal_edit_event'] = 'Muokkaa kalenteritapahtumaa';
$lang['error_dberror'] = 'Tietokantavirhe';
$lang['submit'] = 'L&auml;het&auml;';
$lang['info_sysdflt_editevent_template'] = 'J&auml;rjestelm&auml;n oletus &quot;Muokkaa tapahtumaa&quot;-sivupohja';
$lang['info_sysdflt_myevents_template'] = 'J&auml;rjestelm&auml;n oletus &quot;Omat tapahtumat&quot;-sivupohja';
$lang['prompt_feedit_group'] = 'T&auml;m&auml;n ryhm&auml;n FrontEndUsers-moduulin j&auml;senet voivat lis&auml;t&auml; tapahtumia.';
$lang['prompt_feedit_page'] = 'Oletussivu julkisten sivujen muokkauslomakkeelle.';
$lang['none'] = 'Ei mit&auml;&auml;n';
$lang['owner'] = 'Omistaja';
$lang['cal_editevent_templates'] = 'Tapahtuman muokkaus -lomake';
$lang['info_editevent_template_tab'] = 'Saatavilla olevien sivupohjien lista tapahtuman muokkauslomakkeelle.';
$lang['editeventtemplate_addedit'] = 'Lis&auml;&auml;/muokkaa tapahtuman muokkaus -lomakkeen sivupohjaa';
$lang['cal_myevents_templates'] = 'Omat tapahtumat -lista';
$lang['info_myevents_template_tab'] = 'Saatavilla olevien sivupohjien lista, joilla voi n&auml;ytt&auml;&auml; k&auml;ytt&auml;j&auml;n tapahtumien listan';
$lang['myeventstemplate_addedit'] = 'Lis&auml;&auml; tai poista &quot;Omat tapahtumat&quot; raportin sivupohjaa';
$lang['areyousure_removeconflicting'] = 'T&auml;m&auml; toiminta poistaa tapahtumat, jotka ovat ristiriidassa sellaisten tapahtumien kanssa, jotka eiv&auml;t voi olla p&auml;&auml;llekk&auml;in. Oletko varma, ett&auml; haluat tehd&auml; t&auml;m&auml;n?';
$lang['filter_conflicting'] = 'Suodata p&auml;&auml;llekk&auml;in menev&auml;t tapahtumat';
$lang['overlap_action_remove'] = 'Poista p&auml;&auml;llekk&auml;in menev&auml;t tapahtumat hiljaisesti';
$lang['overlap_action_error'] = 'N&auml;yt&auml; virhe';
$lang['prompt_overlap_action'] = 'Mit&auml; tapahtuu, kun tapahtuman lis&auml;yksess&auml; tai muokkauksessa huomataan p&auml;&auml;llekk&auml;isyys';
$lang['error_event_conflict'] = 'Tapahtuman p&auml;iv&auml;m&auml;&auml;r&auml;t menev&auml;t p&auml;&auml;llekk&auml;in sellaisen tapahtuman kanssa, jonka p&auml;&auml;lle ei voi laittaa toista tapahtumaa';
$lang['cal_info_overlap'] = 'Koskee ainoastaan tapahtumia, joilla on loppumisaika (tai koko p&auml;iv&auml;n kest&auml;vi&auml; tapahtumia)';
$lang['cal_overlap'] = 'Salli uusien tapahtumien menn&auml; p&auml;&auml;llekk&auml;in t&auml;m&auml;n kanssa';
$lang['prompt_overlap_policy'] = 'Tapahtuman p&auml;&auml;llekk&auml;isyys k&auml;yt&auml;nt&ouml;';
$lang['policy_all'] = 'Kaikki tapahtumat voivat menn&auml; p&auml;&auml;llekk&auml;in';
$lang['policy_none'] = 'Tapahtumat eiv&auml;t voi menn&auml; p&auml;&auml;llekk&auml;in';
$lang['policy_individual'] = 'Valitaan tapahtumakohtaisesti';
$lang['lbl_back'] = 'Takaisin';
$lang['lbl_templates'] = 'Sivupohjat';
$lang['textarea'] = 'Tekstikentt&auml;';
$lang['error_calendar_incompatible'] = 'Huomasimme, ett&auml; my&ouml;s kalenterimoduuli on asennettuna. T&auml;m&auml; moduuli ei ole sen kanssa yhteensopiva eik&auml; ne voi olla yht&auml;aikaa asennettuna. Ole hyv&auml; ja poista kalenterimoduuli ensin.';
$lang['error_event_not_found'] = 'Joko tapahtuman tunnistetta ei ole tietokannassa, tai tietokannassa on useampi tapahtuma t&auml;ll&auml; tunnisteella! (%d)';
$lang['first_page'] = '<<';
$lang['prev_page'] = '<';
$lang['next_page'] = '>';
$lang['last_page'] = '>>';
$lang['page_of'] = 'Sivu %d / &amp;d';
$lang['search_results'] = 'Kalenterin hakutulokset';
$lang['search_words'] = 'Hakusanat';
$lang['no_results_found'] = 'Ei tuloksia';
$lang['frequency'] = 'Frekvenssi';
$lang['specified_date'] = 'K&auml;yt&auml; tietty&auml; p&auml;iv&auml;m&auml;&auml;r&auml;&auml;';
$lang['first_sunday'] = 'Kuukauden ensimm&auml;inen sunnuntai';
$lang['first_monday'] = 'Kuukauden ensimm&auml;inen maanantai';
$lang['first_tuesday'] = 'Kuukauden ensimm&auml;inen tiistai';
$lang['first_wednesday'] = 'Kuukauden ensimm&auml;inen keskiviikko';
$lang['first_thursday'] = 'Kuukauden ensimm&auml;inen torstai';
$lang['first_friday'] = 'Kuukauden ensimm&auml;inen perjantai';
$lang['first_saturday'] = 'Kuukauden ensimm&auml;inen lauantai';
$lang['second_sunday'] = 'Kuukauden toinen sunnuntai';
$lang['second_monday'] = 'Kuukauden toinen maanantai';
$lang['second_tuesday'] = 'Kuukauden toinen tiistai';
$lang['second_wednesday'] = 'Kuukauden toinen keskiviikko';
$lang['second_thursday'] = 'Kuukauden toinen torstai';
$lang['second_friday'] = 'Kuukauden toinen perjantai';
$lang['second_saturday'] = 'Kuukauden toinen lauantai';
$lang['third_sunday'] = 'Kuukauden kolmas sunnuntai';
$lang['third_monday'] = 'Kuukauden kolmas maanantai';
$lang['third_tuesday'] = 'Kuukauden kolmas tiistai';
$lang['third_wednesday'] = 'Kuukauden kolmas keskiviikko';
$lang['third_thursday'] = 'Kuukauden kolmas torstai';
$lang['third_friday'] = 'Kuukauden kolmas perjantai';
$lang['third_saturday'] = 'Kuukauden kolmas lauanatai';
$lang['fourth_sunday'] = 'Kuukauden nelj&auml;s sunnuntai';
$lang['fourth_monday'] = 'Kuukauden nelj&auml;s maanantai';
$lang['fourth_tuesday'] = 'Kuukauden nelj&auml;s tiistai';
$lang['fourth_wednesday'] = 'Kuukauden nelj&auml;s keskiviikko';
$lang['fourth_thursday'] = 'Kuukauden nelj&auml;s torstai';
$lang['fourth_friday'] = 'Kuukauden nelj&auml;s perjantai';
$lang['fourth_saturday'] = 'Kuukauden nelj&auml;s lauantai';
$lang['last_sunday'] = 'Kuukauden viimeinen sunnuntai';
$lang['last_monday'] = 'Kuukauden viimeinen maanantai';
$lang['last_tuesday'] = 'Kuukauden viimeinen tiistai';
$lang['last_wednesday'] = 'Kuukauden viimeinen keskiviikko';
$lang['last_thursday'] = 'Kuukauden viimeinen torstai';
$lang['last_friday'] = 'Kuukauden viimeinen perjantai';
$lang['last_saturday'] = 'Kuukauden viimeinen lauantai';
$lang['error_invalid_recur_monthly_freq'] = 'Virheellinen frekvenssi... et voi m&auml;&auml;ritell&auml; sek&auml; tietty&auml; p&auml;iv&auml;m&auml;&auml;r&auml;&auml; JA muita arvoja';
$lang['searchresulttemplate_addedit'] = 'Lis&auml;&auml;/muokkaa hakutulosten sivupohjaa';
$lang['info_searchresult_template_tab'] = 'Saatavilla oleva lista hakutulosten sivupohjista';
$lang['info_sysdflt_searchresult_template'] = 'J&auml;rjestelm&auml;n oletussivupohja hakutuloksille';
$lang['cal_search_result_templates'] = 'Hakutulokset';
$lang['error_query_failed'] = 'Tietokannasta haku ep&auml;onnistui';
$lang['error_search_invalid_dates'] = 'Virheelliset p&auml;iv&auml;m&auml;&auml;r&auml;t';
$lang['text'] = 'Teksti';
$lang['search'] = 'Haku';
$lang['category'] = 'Kategoria';
$lang['info_sysdflt_search_template'] = 'J&auml;rjestelm&auml;n oletussivupohja hakulomakkeelle';
$lang['searchtemplate_addedit'] = 'Lis&auml;&auml;/muokkaa hakulomakkeen sivupohjaa';
$lang['info_search_template_tab'] = 'Saatavilla oleva lista hakulomakkeen sivupohjista';
$lang['cal_search_form_templates'] = 'Hakulomake';
$lang['max'] = 'max.';
$lang['times'] = 'kertaa';
$lang['on'] = 'on ';
$lang['areyousure_uninstall'] = 'Oletko varma, ett&auml; haluat tehd&auml; t&auml;m&auml;n? Jatkaminen poistaa kaikki t&auml;h&auml;n moduuliin liittyv&auml;t tiedot.';
$lang['post_uninstall'] = 'Kalenterimoduuli on poistettu onnistuneesti ja t&auml;h&auml;n moduuliin liittyv&auml;t sivupohjat on poistettu.';
$lang['fieldupdated'] = 'Kentt&auml; p&auml;ivitetty';
$lang['every'] = 'Joka';
$lang['or'] = 'tai';
$lang['update_children'] = 'P&auml;ivit&auml; alatapahtumat';
$lang['error_nocategory'] = 'Sinun t&auml;ytyy valita ainakin yksi kategoria';
$lang['error_nothingselected'] = 'Ei valittu mit&auml;&auml;n poistettavaksi';
$lang['error_eventoverlap'] = 'Antamasi parametrit toistuvalle tapahtumalla aiheuttaisi p&auml;&auml;llekk&auml;isen tapahtuman.';
$lang['recurs'] = 'Toistuu';
$lang['error_invalid_dates'] = 'Yksi tai useampi annettu arvo oli virheellinen';
$lang['sunday'] = 'sunnuntai';
$lang['monday'] = 'maanantai';
$lang['tuesday'] = 'tiistai';
$lang['wednesday'] = 'keskiviikko';
$lang['thursday'] = 'torstai';
$lang['friday'] = 'perjantai';
$lang['saturday'] = 'lauantai';
$lang['abbr_sunday'] = 'su';
$lang['abbr_monday'] = 'ma';
$lang['abbr_tuesday'] = 'ti';
$lang['abbr_wednesday'] = 'ke';
$lang['abbr_thursday'] = 'to';
$lang['abbr_friday'] = 'pe';
$lang['abbr_saturday'] = 'la';
$lang['weekdays'] = 'Viikonp&auml;iv&auml;t';
$lang['plural_daily'] = 'P&auml;iv&auml;&auml;';
$lang['plural_weekly'] = 'Viikkoa';
$lang['plural_monthly'] = 'Kuukautta';
$lang['plural_yearly'] = 'Vuotta';
$lang['no'] = 'Ei';
$lang['daily'] = 'P&auml;ivitt&auml;in';
$lang['weekly'] = 'Viikottain';
$lang['monthly'] = 'Kuukausittain';
$lang['yearly'] = 'Vuosittain';
$lang['interval'] = 'Toista joka';
$lang['cal_recur_details'] = 'Toistuvan tapahtuman tiedot';
$lang['unlimited'] = 'Rajoittamaton';
$lang['max_recur_events'] = 'Alatapahtumien maksimim&auml;&auml;r&auml;';
$lang['use_to_date'] = 'M&auml;&auml;rittele toinen loppumisp&auml;iv&auml;m&auml;&auml;r&auml;?';
$lang['cancel'] = 'Peruuta';
$lang['show_child_events'] = 'N&auml;yt&auml; alatapahtumat <em>(voi aiheuttaa eritt&auml;in pitk&auml;n listan)</em>';
$lang['n/a'] = 'ei mit&auml;&auml;n';
$lang['recurs_until'] = 'Toista kunnes';
$lang['parent'] = 'P&auml;&auml;tapahtuma';
$lang['recur_period'] = 'Toistumisaika';
$lang['filter'] = 'Suodata';
$lang['start_date'] = 'Alkamisp&auml;iv&auml;m&auml;&auml;r&auml;';
$lang['end_date'] = 'Loppumisp&auml;iv&auml;m&auml;&auml;r&auml;';
$lang['info_upcominglist_template_tab'] = 'Saatavilla oleva lista sivupohjista tuleville tapahtumille';
$lang['upcominglisttemplate_addedit'] = 'Lis&auml;&auml;/muokkaa tulevien tapahtumien n&auml;ytt&auml;misen sivupohjia';
$lang['info_sysdflt_upcominglist_template'] = 'J&auml;rjestelm&auml;n oletussivupohja tulevien tapahtumien n&auml;ytt&auml;miseksi';
$lang['info_list_template_tab'] = 'Saatavilla oleva lista sivupohjista tapahtumien listan n&auml;ytt&auml;miseksi';
$lang['listtemplate_addedit'] = 'Lis&auml;&auml;/muokkaa sivupohjaa tapahtumalistan n&auml;ytt&auml;miseksi';
$lang['info_sysdflt_list_template'] = 'J&auml;rjestelm&auml;n oletussivupohja tapahtumalistalle';
$lang['info_event_template_tab'] = 'Saatavilla olevien sivupohjien lista tapahtumien n&auml;ytt&auml;miseksi';
$lang['eventtemplate_addedit'] = 'Lis&auml;&auml;/muokkaa sivupohjaa tapahtuman n&auml;ytt&auml;miseksi';
$lang['info_sysdflt_event_template'] = 'J&auml;rjestelm&auml;n oletus sivupohja tapahtuman n&auml;ytt&auml;miseksi';
$lang['info_calendar_template_tab'] = 'Saatavilla oleva lista sivupohjista kalenterin n&auml;ytt&auml;miseksi';
$lang['calendartemplate_addedit'] = 'Lis&auml;&auml;/muokkaa sivupohjia kalenterin n&auml;ytt&auml;miseksi';
$lang['info_sysdflt_calendar_template'] = 'J&auml;rjestelm&auml;n oletussivupohja kalenterin n&auml;ytt&auml;miseksi';
$lang['info_sysdflt_template'] = 'T&auml;m&auml; lomake m&auml;&auml;rittelee sivupohjan, jota k&auml;ytet&auml;&auml;n, kun klikkaat &quot;Uusi sivupohja&quot;-painiketta v&auml;lilehdess&auml;. T&auml;m&auml;n arvon muuttamiselle ei ole vaikutusta heti t&auml;m&auml;n moduulin luomille sivuille.';
$lang['eventdesc-EventAdded'] = 'Kutsutaan kalenteritapahtuman lis&auml;&auml;misen j&auml;lkeen';
$lang['eventdesc-EventEdited'] = 'Kutsutaan kalenteritapahtuman muutoksen j&auml;lkeen';
$lang['eventdesc-EventDeleted'] = 'Kutsutaan tapahtuman poiston j&auml;lkeen';
$lang['eventdesc-CategoryAdded'] = 'Kutsutaan kategorian lis&auml;&auml;misen j&auml;lkeen';
$lang['eventdesc-CategoryEdited'] = 'Kutsutaan kategorian muutoksen j&auml;lkeen';
$lang['eventdesc-CategoryDeleted'] = 'Kutsutaan kategorian poiston j&auml;lkeen';
$lang['eventhelp-EventAdded'] = '<p>Sent when a calendar event is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;event_title\&quot; - Event Title</li>
<li>\&quot;event_summary\&quot; - Summary Text</li>
<li>\&quot;event_details\&quot; - Detailed Description</li>
<li>\&quot;event_date_start\&quot; - The event start date/time</li>
<li>\&quot;event_date_end\&quot; - The event end date/time</li>
<li>\&quot;event_created_by\&quot; - The userid of the author</li>
<li>\&quot;event_id\&quot; - The event id</li>
</ul>
';
$lang['eventhelp-EventEdited'] = '<p>Sent when a calendar event is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;event_title\&quot; - Event Title</li>
<li>\&quot;event_summary\&quot; - Summary Text</li>
<li>\&quot;event_details\&quot; - Detailed Description</li>
<li>\&quot;event_date_start\&quot; - The event start date/time</li>
<li>\&quot;event_date_end\&quot; - The event end date/time</li>
<li>\&quot;event_created_by\&quot; - The userid of the author</li>
<li>\&quot;event_id\&quot; - The event id</li>
</ul>
';
$lang['eventhelp-EventDeleted'] = '<p>Sent when a calendar event is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;event_id\&quot; - The event id</li>
</ul>
';
$lang['eventhelp-CategoryAdded'] = '<p>Sent when a calendar category is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - The category id</li>
</ul>
';
$lang['eventhelp-CategoryEdited'] = '<p>Sent when a calendar category is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - The category id</li>
<li>\&quot;category_name\&quot; - The category name</li>
<li>\&quot;category_order\&quot; - The category sort order</li>
</ul>
';
$lang['eventhelp-CategoryDeleted'] = '<p>Sent when a calendar category is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - The category id</li>
<li>\&quot;category_name\&quot; - The category name</li>
<li>\&quot;category_order\&quot; - The category sort order</li>
</ul>
';
$lang['msg_eventadded'] = 'Tapahtuma lis&auml;tty';
$lang['error_noeventname'] = 'Tapahtumalla t&auml;ytyy olla nimi';
$lang['error_noupload'] = 'Virhe: Palvelimelle siirretty&auml; tiedostoa ei l&ouml;ytynyt';
$lang['error_invalidfilename'] = 'Virhe: Tiedoston siirtoa ei voida hyv&auml;ksy&auml;';
$lang['error_problemwithupload'] = 'Virhe: Tiedoston siirrossa tapahtui virhe';
$lang['error_filecopyfailed'] = 'Virhe: Tiedoston kopioinnissa lopulliseen sijaintiinsa tapahtui virhe';
$lang['error_fileexists'] = 'Virhe: Samanniminen tiedosto on jo olemassa';
$lang['error_csvfilenotfound'] = 'Virhe:  CSV-tiedostoa ei voitu l&ouml;yt&auml;&auml;';
$lang['error_cantopenfile'] = 'Virhe: Tiedostoa ei voida avata';
$lang['error_categoryexists'] = 'Virhe: Kategoria nimell&auml; %s on jo olemassa';
$lang['cal_id'] = 'ID';
$lang['cal_calendar'] = 'Kalenteri';
$lang['cal_default_templates'] = 'Oletukset';
$lang['cal_description'] = 'Monipuolinen moduuli, jonka avulla voit n&auml;ytt&auml;&auml; tapahtumia useissa eri muodoissa.';
$lang['cal_addevent'] = 'Lis&auml;&auml; tapahtuma';
$lang['cal_import_events'] = 'Tuo tapahtumia';
$lang['cal_events'] = 'Tapahtumat';
$lang['cal_categories'] = 'Kategoriat';
$lang['cal_calendar_template'] = 'Kalenteri';
$lang['cal_list_template'] = 'Tapahtumalista';
$lang['cal_upcominglist_template'] = 'Tulevat tapahtumat';
$lang['cal_event_template'] = 'Tapahtuma';
$lang['cal_settings'] = 'Asetukset';
$lang['cal_prev'] = '&laquo; Edellinen';
$lang['cal_next'] = 'Seuraava &raquo;';
$lang['cal_categories_updated'] = 'Kategoriat p&auml;ivitetty';
$lang['cal_settings_updated'] = 'Asetukset p&auml;ivitetty';
$lang['cal_add_event'] = 'Lis&auml;&auml; tapahtuma';
$lang['cal_edit'] = 'Muokkaa';
$lang['cal_delete'] = 'Poista';
$lang['cal_areyousure'] = 'Oletko varma?';
$lang['cal_update_template'] = 'P&auml;ivit&auml; pohja';
$lang['cal_sunday'] = 'sunnuntai';
$lang['cal_monday'] = 'maanantai';
$lang['cal_tuesday'] = 'tiistai';
$lang['cal_wednesday'] = 'keskiviikko';
$lang['cal_thursday'] = 'torstai';
$lang['cal_friday'] = 'perjantai';
$lang['cal_saturday'] = 'lauantai';
$lang['cal_sun'] = 'su';
$lang['cal_mon'] = 'ma';
$lang['cal_tues'] = 'ti';
$lang['cal_wed'] = 'ke';
$lang['cal_thurs'] = 'to';
$lang['cal_fri'] = 'pe';
$lang['cal_sat'] = 'la';
$lang['cal_january'] = 'tammikuu';
$lang['cal_february'] = 'helmikuu';
$lang['cal_march'] = 'maaliskuu';
$lang['cal_april'] = 'huhtikuu';
$lang['cal_may'] = 'toukokuu';
$lang['cal_june'] = 'kes&auml;kuu';
$lang['cal_july'] = 'hein&auml;kuu';
$lang['cal_august'] = 'elokuu';
$lang['cal_september'] = 'syyskuu';
$lang['cal_october'] = 'lokakuu';
$lang['cal_november'] = 'marraskuu';
$lang['cal_december'] = 'joulukuu';
$lang['cal_add'] = 'Lis&auml;&auml;';
$lang['cal_update'] = 'P&auml;ivit&auml;';
$lang['cal_event'] = 'Tapahtuma';
$lang['cal_date'] = 'P&auml;iv&auml;';
$lang['cal_summary'] = 'Tiivistelm&auml;';
$lang['cal_details'] = 'Lis&auml;tiedot';
$lang['cal_more'] = 'Lis&auml;&auml; &raquo;';
$lang['cal_return'] = 'Palaa';
$lang['cal_to'] = ' - ';
$lang['cal_past_events'] = 'Menneet tapahtumat';
$lang['cal_upcoming_events'] = 'Tulevat tapahtumat';
$lang['cal_any_category'] = 'Kaikki kategoriat';
$lang['cal_show_only_events_in'] = 'N&auml;yt&auml; vain ';
$lang['cal_filter_by'] = 'Suodata otsikko';
$lang['cal_go'] = 'Mene';
$lang['cal_title'] = 'Otsikko';
$lang['cal_fromdate'] = 'Mist&auml;';
$lang['cal_todate'] = 'Mihin';
$lang['cal_update_categories'] = 'P&auml;ivit&auml; kategoriat';
$lang['cal_language'] = 'Kieli';
$lang['cal_updatesettings'] = 'P&auml;ivit&auml; asetukset';
$lang['cal_use_twelve_hour_clock'] = 'K&auml;ytet&auml;&auml;nk&ouml; pudotusvalikoissa 12-tunnin kelloa?';
$lang['cal_default_category'] = 'Oletuskategoria';
$lang['cal_update_fields'] = 'P&auml;ivit&auml; kent&auml;t';
$lang['force_category'] = 'Pakota v&auml;hint&auml;&auml;n yksi kategoria';
$lang['showpastyears'] = 'Kuinka monta vuotta menneisyyteen on sallittua';
$lang['showfutureyears'] = 'Kuinka monta vuotta tulevaisuuteen on sallittua';
$lang['hidesummary'] = 'Piilotetaanko yhteenvetokentt&auml;';
$lang['hidecontent'] = 'Piilotetaanko sis&auml;lt&ouml;kentt&auml;';
$lang['category_reminder'] = 'Valitse tapahtumalle yksi tai useampia kategoria';
$lang['module_example_stylesheet'] = 'CSS-esimerkki kalenterille';
$lang['error_permission'] = 'Tarvitset asiaankuluvat oikeudet (%s) t&auml;h&auml;n toiminnallisuuteen';
$lang['install_postmessage'] = 'Varmista, ett&auml; lis&auml;&auml;t oikeuden &quot;Muokata kalenteria&quot; niille k&auml;ytt&auml;jille, jotka yll&auml;pit&auml;v&auml;t kalenteritapahtumia.';
$lang['deletetagged'] = 'Poista valitut tapahtumat';
$lang['confirmdeletetagged'] = 'Haluatko varmasti poistaa n&auml;m&auml; tapahtumat?';
$lang['taggeddeleted'] = 'Valitut tapahtumat poistettu';
$lang['templates'] = 'Sivupohjat';
$lang['template_help'] = 'Sivupohjien ohje';
$lang['file_templates'] = 'Tiedostopohjat';
$lang['addtemplate'] = 'Lis&auml;&auml; sivupohja';
$lang['template'] = 'Sivupohja';
$lang['templatenametext'] = 'Sivupohjan nimi';
$lang['edittemplate'] = 'Muokkaa sivupohjaa';
$lang['deletetemplate'] = 'Poista sivupohja';
$lang['newtemplate'] = 'Uuden sivupohjan nimi';
$lang['templatenameexists'] = 'Virhe: Samanniminen sivupohja on jo olemassa. Valitse toinen nimi';
$lang['templateimported'] = 'Pohja tuotiin onnistuneesti tietokantaan ja on nyt asennettu k&auml;ytett&auml;v&auml;ksi.';
$lang['view_default_stylesheet'] = 'N&auml;yt&auml; oletustyylisivu (CSS)';
$lang['filename'] = 'Tiedostonimi';
$lang['importtemplate'] = 'Tuo sivupohja';
$lang['template_deleted'] = 'Sivupohja poistettu onnistuneesti tietokannasta';
$lang['updatetemplatesuccess'] = 'Sivupohja p&auml;ivitetty onnistuneesti';
$lang['updatetemplatefailure'] = 'Sivupohjan p&auml;ivityksess&auml; tapahtui virhe';
$lang['settingssaved'] = 'Asetukset tallennettu onnistuneesti';
$lang['categorydeleted'] = 'Kategoria poistettu';
$lang['categoryupdated'] = 'Kategoria p&auml;ivitetty';
$lang['categoryadded'] = 'Kategoria lis&auml;tty';
$lang['eventdeleted'] = 'Tapahtuma poistettu';
$lang['eventupdated'] = 'Tapahtuma p&auml;ivitetty';
$lang['default_page_error'] = 'Virhe: Sinun t&auml;ytyy asettaa oletussivu, jotta voit k&auml;ytt&auml;&auml; kalenteria sievien URL-osoitteiden ollessa p&auml;&auml;ll&auml;. Mene kalenterin asetuksiin ja valitse oletussivu.';
$lang['time_at'] = 'klo';
$lang['type'] = 'Tyyppi';
$lang['name'] = 'Nimi';
$lang['order'] = 'J&auml;rjestys';
$lang['fieldadded'] = 'Kentt&auml; lis&auml;tty onnistuneesti';
$lang['fielddeleted'] = 'Kentt&auml; poistettu';
$lang['fields'] = 'Mukautetut kent&auml;t';
$lang['textfield'] = 'Tekstikentt&auml;';
$lang['uploadfield'] = 'Tiedostonlatauskentt&auml;';
$lang['description'] = '<p>Calendar is a module for displaying events on your page. When the
		module is installed, a Calendar admin page is added to the content menu
		that will allow you to manage your events.</p>';
$lang['defaultcalendarpage'] = 'Kalenterin sis&auml;lt&auml;v&auml; oletussivu. T&auml;m&auml;n sivun tulee sis&auml;lt&auml;&auml; Smarty-tagi, joka kutsuu kalenteria. T&auml;llainen vaaditaan, jos k&auml;yt&auml;t kaunistettuja URLeja.';
$lang['uploaddirectory'] = 'Hakemisto palvelimelle siirretyille tiedostoille';
$lang['uploadfiletypes'] = 'Sallitut tiedostotyypit';
$lang['uploadunique'] = 'Varmista uniikit tiedostonimet';
$lang['thumb_width'] = 'Pienoiskuvan leveys';
$lang['thumb_height'] = 'Pienoiskuvan korkeus';
$lang['large_width'] = 'T&auml;ysikokoisen kuvan leveys';
$lang['large_height'] = 'T&auml;ysikokoisen kuvan korkeus';
$lang['cal_recur_period'] = 'Toistuu';
$lang['cal_recur_until'] = 'Toistuu kunnes';
$lang['help_template'] = '<p><b>Print Author Name:</b></p>
<code>Author: {$event.authorname}</code>
';
$lang['cal_help'] = '<h3>Notice:</h3>
<p>Version 1.0 of the Calguy Calendar module is a complete fork of the old calendar module.  However, this module is not compatible in any way with the other module.</p>
<h3>What does this do?</h3>
<p>Calguys Calendar is a module for displaying events on your page. When the
module is installed, a &amp;quot;Calguys Calendar&amp;quot; admin page is added to the plugins menu
that will allow you to manage your events.</p>
<h3>Security</h3>
<p>The user must belong to a group with the &#039;Modify Calendar&#039; permission
in order to add, edit, or delete calendar event entries.</p>
<h3>How do I use it?</h3>
<ol>
  <li>Put the cms_module tag in the page content. Make sure it is not enclosed in &amp;lt;pre&amp;gt;...&amp;lt;/pre&amp;gt; tags.  You will need to view source code for this.  The code would look something like:<br />
  <tt>{cms_module module=&quot;CGCalendar&quot;}</tt><br />
  <li>Style the calendar appropriately for your display (an example stylesheet is provided for this purpose)</li>
</ol>
<br/>
<p><b>To attach the sample stylesheet to your template:</b></p>
<ol>
<li>Go to &quot;Layout -> Templates&quot;</li>
<li>Click the CSS icon (Attach Stylesheet to Template) button to the right of your template</li>
<li>Choose &quot;Calguys Calendar CSS example&quot; from the drop-down menu.</li>
<li>Click the &quot;Add a Stylesheet&quot; button.</li>
</ol>
<br/>
<h3>Parameters</h3>
<table border=0 cellpadding=3 cellspacing=0>
  <tr>
     <td>action</td>
     <td>Acceptable values:<br>
        &quot;default&quot; - Specifies the default action, works in conjunction with the &quot;display&quot; parameter below.<br/>
	&quot;search&quot; - Display a form for advanced searching of calendar events.<br/>
        &quot;myevents&quot; - Display a list of all of a users events, and allow adding, editing or deleting those events<br/>
        &quot;addedit_event&quot; - Display a form allowing to add or edit a single event.;
     </td>
  </tr>

  <tr>
     <td>display</td>
     <td>Acceptable values:<br>
	 &quot;calendar&quot; - displays events for the current month in a traditional grid.  Inclues links to prev. and next months.<br/>
	 &quot;event&quot; - display a detail report for a specific event.  To use this display mode, the event_id parameter must be specified.<br/>
	 &quot;list&quot; - displays events for the current month as a list.  Includes links to prev. and next months.<br/>
	 &quot;yearlist&quot; - displays events for the current year in a list.  Includes links to prev. and next years.<br/>
	 &quot;pastlist&quot; - displays all past events.  No prev/next links.<br/>
	 &quot;upcominglist&quot; - displays all upcoming events.  No prev/next links.<br/>
		Defaults to &quot;calendar&quot; <em>(optional)</em>
     </td>
  </tr>

  <tr>
     <td>category</td>
     <td>Only display items for that category. Leaving unset, will show all categories. Note that
	 you can limit to multiple categories by separating each one with a comma.<em>(optional)</em></td>
  </tr>

  <tr>
     <td>month</td>
     <td>Display entries for a particular month. If year is not set, then the current year is
	 assumed. This option only works if display is set to &quot;list&quot; or &quot;calendar&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>year</td>
     <td>Display entries for a particular year.
	This option only works if display is set to &quot;list&quot; or &quot;calendar&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>limit</td>
     <td>Set to the maximum number of events to display. This option only works if display is set to &quot;list&quot;, &quot;pastlist&quot; or &quot;upcominglist&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>first_day_of_week</td>
     <td>Set to the first day of the week as a number between 0 and 6 (0 = Sunday). Default is 1 (Monday).
	 This option only works if display is set to &quot;calendar&quot;. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>use_session</td>
	 <td>Use session variables to store the specifications of the calendar. This will allow a calendar to remember its settings over numerous page views and while scrolling to different months.  In the search form it allows saving the search settings until the browser is reset.  Default is false.  If specified, the value should contain a unique identifier for that calendar instance.  This option only works if display is set to &quot;calendar&quot; or &quot;list&quot;, or if &quot;action&quot; is search. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>inline</td>
     <td>Set to 1 to set all of the event links to inlined mode (they will replace the oringal tag).  Default is 0. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>reverse</td>
     <td>Set to true to display events in reverse chronological order. Applicable to &quot;list&quot;, &quot;pastlist&quot; and &quot;upcominglist&quot; displays. Default is false. For the &quot;pastlist&quot;, reverse=true is assumed.<em>(optional)</em></td>
  </tr>

  <tr>
     <td>detailpage=&quot;pagealias&quot;</td>
     <td>Page to display Calendar event details in. This can either be a page alias or an id. Used to allow details to be displayed in a different template from the summary. Default is current page. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>columns</td>
     <td>Makes Calendar output only a subset of relevant events for allowing displaying in columns. Allowed values 1/2. Default is 1. Implemented for upcominglist and pastlist only. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>columnstyle</td>
     <td>If columns=2 this parameter sets whether the order of events in columns should be organized horizontally (0) or vertically (1). Default is 1. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>currentcolumn</td>
     <td>If columns=2 this indicated whether Calendar should display content of column 1 or 2. Allowed values 1/2. Default is 1. <em>(optional)</em></td>
  </tr>

  <tr>
     <td>event_id</td>
     <td>Used with the display=event mode, this parameter allows you to display information about a specific event on demand.</td>
  </tr>

  <tr>
     <td>limit</td>
     <td>Used with the list displays, this parameter allows specifying a maximum number of events to display, and then provides pagination capabilities.</td>
  </tr>

  <tr>
     <td>calendartemplate</td>
     <td>Used with display=calendar, this parameter allows you to specify a non default calendar template.</td>
  </tr>

  <tr>
     <td>eventtemplate</td>
     <td>Used with display=event, or you can also specify this parameter on any Calendar module call, this parameter allows you to specify a non default event template.</td>
  </tr>

  <tr>
     <td>listtemplate</td>
     <td>Used with display=list, this parameter allows you to specify a non default list template.</td>
  </tr>

  <tr>
     <td>upcominglisttemplate</td>
     <td>Used with display=upcominglist, this parameter allows you to specify a non default upcominglist template.</td>
  </tr>

  <tr>
     <td>unique_only</td>
     <td>Used with display=upcominglist, and with action=search, this parameter allows you to specify that only one event of a certain type should be returned&#039;;
  </tr>

</table>

<h3>Custom Fields</h3>
<p>It is possible to define a number of custom fields to associate with each event using the Fields tab in the admin. Once one or more fields has been defined the values of that field for each event can be set using the events tab in the admin. These field values can be rendered using a template using the syntax event.fields.fieldname. Hint - insert {debug} into your template see all the data passed to the template.</p>

<h3>Examples</h3>
<h4>Example of allowing Comments on Calendar events</h4>
<p>Install the Comments module and put this in your Calendar &quot;Event Template&quot;:</p>
<pre>{cms_module module=&#039;comments&#039; modulename=&#039;CGCalendar&#039; pageid=$event.event_id}</pre>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>Discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['utma'] = '156861353.913577157.1292870007.1307535822.1307565405.18';
$lang['utmz'] = '156861353.1302546643.10.5.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
$lang['qca'] = 'P0-584376928-1292870006667';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>